.. _cloudman-api-docs:

===============================================
API documentation for interacting with CloudMan
===============================================

CloudManLauncher
----------------

.. autoclass:: bioblend.cloudman.launch.CloudManLauncher
    :members:
    :undoc-members:

.. _cloudman-instance-api:

CloudManInstance
----------------

.. automodule:: bioblend.cloudman
    :members:
    :undoc-members:
